# UserPermissionSetResourceSpacePermissions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**_none** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**administer_system** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**process_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**process_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**variable_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**variable_edit_unscoped** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**variable_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**variable_view_unscoped** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**release_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**release_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**release_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**release_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**defect_report** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**defect_resolve** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**deployment_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**deployment_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**deployment_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**environment_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**environment_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**environment_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**environment_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**artifact_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**artifact_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**artifact_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**artifact_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**feed_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**event_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**library_variable_set_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**library_variable_set_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**library_variable_set_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**library_variable_set_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_group_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_group_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_group_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**project_group_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**team_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**team_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**team_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**team_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**user_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**user_invite** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**user_role_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**user_role_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**task_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**task_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**task_cancel** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**task_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**interruption_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**interruption_submit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**interruption_view_submit_responsible** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**built_in_feed_push** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**built_in_feed_administer** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**built_in_feed_download** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**action_template_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**action_template_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**action_template_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**action_template_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**lifecycle_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**lifecycle_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**lifecycle_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**lifecycle_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**account_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**account_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**account_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**account_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tenant_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tenant_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tenant_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tenant_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tag_set_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tag_set_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**tag_set_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_policy_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_policy_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_policy_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**machine_policy_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**proxy_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**proxy_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**proxy_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**proxy_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**subscription_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**subscription_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**subscription_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**subscription_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**trigger_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**trigger_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**trigger_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**trigger_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**certificate_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**certificate_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**certificate_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**certificate_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**certificate_export_private_key** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**user_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**configure_server** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**feed_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**worker_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**worker_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**run_system** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**space_edit** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**space_view** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**space_delete** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**space_create** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 
**package_metadata_push** | [**list[UserPermissionRestriction]**](UserPermissionRestriction.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


